Python: module cgi

cgi (version 0.0.1) | index cgi.py

`This tool runs CLI scripts and displays output in a Web Interface.
This file implements a CGI server to customize resquests
and responses with non-python script or executable.`

Functions
`` |  | bin(environ: os._Environ, user: ~User, server: ~Server, script_name: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function reloads the configuration.`

Data
`` |  | Dict = typing.Dict List = typing.List PIPE = -1 Server = ~Server Tuple = typing.Tuple User = ~User __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021, 2022, 2023 Mau...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tool runs CLI scripts and displays output ... responses with non-python script or executable.\n' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts' copyright = '\nWebScripts Copyright (C) 2021, 2022, 2023 Mau...ome to redistribute it\nunder certain conditions.\n' license = 'GPL-3.0 License'

Author
`` |  | Maurice Lambert